==> chromium-93.0.4536.2.tar.xz: chromium-93.0.4536.2/chrome/browser/policy/chrome_browser_cloud_management_controller_android.h <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_POLICY_CHROME_BROWSER_CLOUD_MANAGEMENT_CONTROLLER_ANDROID_H_
#define CHROME_BROWSER_POLICY_CHROME_BROWSER_CLOUD_MANAGEMENT_CONTROLLER_ANDROID_H_

#include "components/enterprise/browser/controller/chrome_browser_cloud_management_controller.h"

#include "chrome/browser/enterprise/reporting/reporting_delegate_factory_desktop.h"

namespace policy {

// Android implementation of the platform-specific operations of CBCMController.
class ChromeBrowserCloudManagementControllerAndroid
    : public ChromeBrowserCloudManagementController::Delegate {
 public:
  ChromeBrowserCloudManagementControllerAndroid();
  ChromeBrowserCloudManagementControllerAndroid(
      const ChromeBrowserCloudManagementControllerAndroid&) = delete;
  ChromeBrowserCloudManagementControllerAndroid& operator=(
      const ChromeBrowserCloudManagementControllerAndroid&) = delete;

  ~ChromeBrowserCloudManagementControllerAndroid() override;

  // ChromeBrowserCloudManagementController::Delegate implementation.
  void SetDMTokenStorageDelegate() override;
  int GetUserDataDirKey() override;
  base::FilePath GetExternalPolicyDir() override;
  NetworkConnectionTrackerGetter CreateNetworkConnectionTrackerGetter()
      override;
  void InitializeOAuthTokenFactory(
      scoped_refptr<network::SharedURLLoaderFactory> url_loader_factory,
      PrefService* local_state) override;
  void StartWatchingRegistration(
      ChromeBrowserCloudManagementController* controller) override;
  bool WaitUntilPolicyEnrollmentFinished() override;
  bool IsEnterpriseStartupDialogShowing() override;
  void OnServiceAccountSet(CloudPolicyClient* client,
                           const std::string& account_email) override;
  void ShutDown() override;
  MachineLevelUserCloudPolicyManager* GetMachineLevelUserCloudPolicyManager()
      override;
  DeviceManagementService* GetDeviceManagementService() override;
  scoped_refptr<network::SharedURLLoaderFactory> GetSharedURLLoaderFactory()
      override;
  scoped_refptr<base::SingleThreadTaskRunner> GetBestEffortTaskRunner()
      override;

  void SetGaiaURLLoaderFactory(scoped_refptr<network::SharedURLLoaderFactory>
                                   url_loader_factory) override;
};

}  // namespace policy

#endif  // CHROME_BROWSER_POLICY_CHROME_BROWSER_CLOUD_MANAGEMENT_CONTROLLER_ANDROID_H_

==> chromium-93.0.4577.62.tar.xz: chromium-93.0.4577.62/chrome/browser/policy/chrome_browser_cloud_management_controller_android.h <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_POLICY_CHROME_BROWSER_CLOUD_MANAGEMENT_CONTROLLER_ANDROID_H_
#define CHROME_BROWSER_POLICY_CHROME_BROWSER_CLOUD_MANAGEMENT_CONTROLLER_ANDROID_H_

#include "components/enterprise/browser/controller/chrome_browser_cloud_management_controller.h"

#include <memory>

#include "chrome/browser/enterprise/reporting/reporting_delegate_factory_desktop.h"

namespace policy {

// Android implementation of the platform-specific operations of CBCMController.
class ChromeBrowserCloudManagementControllerAndroid
    : public ChromeBrowserCloudManagementController::Delegate {
 public:
  ChromeBrowserCloudManagementControllerAndroid();
  ChromeBrowserCloudManagementControllerAndroid(
      const ChromeBrowserCloudManagementControllerAndroid&) = delete;
  ChromeBrowserCloudManagementControllerAndroid& operator=(
      const ChromeBrowserCloudManagementControllerAndroid&) = delete;

  ~ChromeBrowserCloudManagementControllerAndroid() override;

  // ChromeBrowserCloudManagementController::Delegate implementation.
  void SetDMTokenStorageDelegate() override;
  int GetUserDataDirKey() override;
  base::FilePath GetExternalPolicyDir() override;
  NetworkConnectionTrackerGetter CreateNetworkConnectionTrackerGetter()
      override;
  void InitializeOAuthTokenFactory(
      scoped_refptr<network::SharedURLLoaderFactory> url_loader_factory,
      PrefService* local_state) override;
  void StartWatchingRegistration(
      ChromeBrowserCloudManagementController* controller) override;
  bool WaitUntilPolicyEnrollmentFinished() override;
  bool IsEnterpriseStartupDialogShowing() override;
  void OnServiceAccountSet(CloudPolicyClient* client,
                           const std::string& account_email) override;
  void ShutDown() override;
  MachineLevelUserCloudPolicyManager* GetMachineLevelUserCloudPolicyManager()
      override;
  DeviceManagementService* GetDeviceManagementService() override;
  scoped_refptr<network::SharedURLLoaderFactory> GetSharedURLLoaderFactory()
      override;
  scoped_refptr<base::SingleThreadTaskRunner> GetBestEffortTaskRunner()
      override;
  void SetGaiaURLLoaderFactory(scoped_refptr<network::SharedURLLoaderFactory>
                                   url_loader_factory) override;
  bool ReadyToCreatePolicyManager() override;
  bool ReadyToInit() override;
  void DeferInitialization(base::OnceClosure callback) override;

 private:
  // Active while it can't be determined if enrollment token is set by non-CBCM
  // policies.
  std::unique_ptr<PolicyService::Observer> policy_service_observer_;
};

}  // namespace policy

#endif  // CHROME_BROWSER_POLICY_CHROME_BROWSER_CLOUD_MANAGEMENT_CONTROLLER_ANDROID_H_
